===============================
DBaaS Foreman
===============================


.. image:: https://img.shields.io/pypi/v/dbaas_foreman.svg
        :target: https://pypi.python.org/pypi/dbaas_foreman

.. image:: https://img.shields.io/travis/globocom/dbaas_foreman.svg
        :target: https://travis-ci.org/globocom/dbaas_foreman


DBaaS Foreman is a simple foreman api wrapper for DBaaS


* Free software: MIT license


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

